---
jupyter:
  kernelspec:
    display_name: Stata
    language: stata
    name: stata
---

```{stata}
// This notebook uses the stata_kernel: https://github.com/kylebarron/stata_kernel
```

```{stata}
use http://www.stata-press.com/data/r13/auto
```

```{stata}
summarize
```

```{stata}
scatter weight length
```
